@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: /sd/opensource/trunk/Audio-Scan/libid3tag/ucs4.c 52786 2009-04-07T15:38:04.236288Z andy  $
+ * $Id: /sd/opensource/trunk/Audio-Scan/libid3tag/ucs4.c 59610 2009-10-17T01:38:41.390924Z andy  $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -126,7 +126,7 @@ id3_latin1_t *id3_ucs4_latin1duplicate(id3_ucs4_t const *ucs4)
   id3_latin1_t *latin1;
 
 #ifdef _MSC_VER
-  Newx(latin1, id3_ucs4_latin1size(ucs4), id3_latin1_t);
+  New(0, latin1, id3_ucs4_latin1size(ucs4), id3_latin1_t);
 #else
   latin1 = malloc(id3_ucs4_latin1size(ucs4) * sizeof(*latin1));
 #endif
@@ -145,7 +145,7 @@ id3_utf16_t *id3_ucs4_utf16duplicate(id3_ucs4_t const *ucs4)
   id3_utf16_t *utf16;
 
 #ifdef _MSC_VER
-  Newx(utf16, id3_ucs4_utf16size(ucs4), id3_utf16_t);
+  New(0, utf16, id3_ucs4_utf16size(ucs4), id3_utf16_t);
 #else
   utf16 = malloc(id3_ucs4_utf16size(ucs4) * sizeof(*utf16));
 #endif
@@ -164,7 +164,7 @@ id3_utf8_t *id3_ucs4_utf8duplicate(id3_ucs4_t const *ucs4)
   id3_utf8_t *utf8;
 
 #ifdef _MSC_VER
-  Newx(utf8, id3_ucs4_utf8size(ucs4), id3_utf8_t);
+  New(0, utf8, id3_ucs4_utf8size(ucs4), id3_utf8_t);
 #else
   utf8 = malloc(id3_ucs4_utf8size(ucs4) * sizeof(*utf8));
 #endif
@@ -193,7 +193,7 @@ id3_ucs4_t *id3_ucs4_duplicate(id3_ucs4_t const *src)
   id3_ucs4_t *ucs4;
 
 #ifdef _MSC_VER
-  Newx(ucs4, id3_ucs4_size(src), id3_ucs4_t);
+  New(0, ucs4, id3_ucs4_size(src), id3_ucs4_t);
 #else
   ucs4 = malloc(id3_ucs4_size(src) * sizeof(*ucs4));
 #endif
